==> openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.16.1-1.tar.gz: openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.16.1-1/pkg/eventing/v1beta1/client_mock_test.go <==
// Copyright © 2019 The Knative Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package v1beta1

import (
	"testing"
	"time"

	v1beta1 "knative.dev/eventing/pkg/apis/eventing/v1beta1"
)

func TestMockKnClient(t *testing.T) {

	client := NewMockKnEventingClient(t)

	recorder := client.Recorder()

	// Record all services
	recorder.GetTrigger("hello", nil, nil)
	recorder.CreateTrigger(&v1beta1.Trigger{}, nil)
	recorder.DeleteTrigger("hello", nil)
	recorder.ListTriggers(nil, nil)
	recorder.UpdateTrigger(&v1beta1.Trigger{}, nil)

	recorder.CreateBroker(&v1beta1.Broker{}, nil)
	recorder.GetBroker("foo", nil, nil)
	recorder.DeleteBroker("foo", time.Duration(10)*time.Second, nil)
	recorder.ListBrokers(nil, nil)

	// Call all service
	client.GetTrigger("hello")
	client.CreateTrigger(&v1beta1.Trigger{})
	client.DeleteTrigger("hello")
	client.ListTriggers()
	client.UpdateTrigger(&v1beta1.Trigger{})

	client.CreateBroker(&v1beta1.Broker{})
	client.GetBroker("foo")
	client.DeleteBroker("foo", time.Duration(10)*time.Second)
	client.ListBrokers()

	// Validate
	recorder.Validate()
}

==> openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.22.0-3.tar.gz: openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.22.0-3/pkg/eventing/v1beta1/client_mock_test.go <==
// Copyright © 2019 The Knative Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package v1beta1

import (
	"context"
	"testing"
	"time"

	v1beta1 "knative.dev/eventing/pkg/apis/eventing/v1beta1"
)

func TestMockKnClient(t *testing.T) {

	client := NewMockKnEventingClient(t)

	recorder := client.Recorder()

	// Record all services
	recorder.GetTrigger("hello", nil, nil)
	recorder.CreateTrigger(&v1beta1.Trigger{}, nil)
	recorder.DeleteTrigger("hello", nil)
	recorder.ListTriggers(nil, nil)
	recorder.UpdateTrigger(&v1beta1.Trigger{}, nil)

	recorder.CreateBroker(&v1beta1.Broker{}, nil)
	recorder.GetBroker("foo", nil, nil)
	recorder.DeleteBroker("foo", time.Duration(10)*time.Second, nil)
	recorder.ListBrokers(nil, nil)

	// Call all service
	ctx := context.Background()
	client.GetTrigger(ctx, "hello")
	client.CreateTrigger(ctx, &v1beta1.Trigger{})
	client.DeleteTrigger(ctx, "hello")
	client.ListTriggers(ctx)
	client.UpdateTrigger(ctx, &v1beta1.Trigger{})

	client.CreateBroker(ctx, &v1beta1.Broker{})
	client.GetBroker(ctx, "foo")
	client.DeleteBroker(ctx, "foo", time.Duration(10)*time.Second)
	client.ListBrokers(ctx)

	// Validate
	recorder.Validate()
}
